Sphinx-Test-Reports
===================

.. image:: docs/_static/sphinx-test-reports-logo.png

Sphinx-Test-Reports shows test results of your unit tests inside your sphinx documentation.


Functions
---------

* Shows test results of **junit based test xml reports** as table
* Shows test environment information of **tox-envreport based json reports** as table


